README
=======

./kamaki is a multipurpose, interactive command-line tool and also a client
development API for managing clouds.

As a development API, it is an initial implementation of the Synnefo API
( http://www.synnefo.org cloud management software extends OpenStack ), while
preserving compatibility with the OpenStack API.

